# Table of Contents

- [data-privacy-statement-sap-leanix-workspace](<./data-privacy-statement-sap-leanix-workspace.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Data Privacy Statement: SAP LeanIX Workspace](<./Data-Privacy-Statement-SAP-LeanIX-Workspace.md>)
  - [1. Purpose and scope](<./Data-Privacy-Statement-SAP-LeanIX-Workspace/1.-Purpose-and-scope.md>)
  - [2. Data Controller](<./Data-Privacy-Statement-SAP-LeanIX-Workspace/2.-Data-Controller.md>)
  - [3. Scope of Processing](<./Data-Privacy-Statement-SAP-LeanIX-Workspace/3.-Scope-of-Processing.md>)
  - [4. The Rights of Users](<./Data-Privacy-Statement-SAP-LeanIX-Workspace/4.-The-Rights-of-Users.md>)
  - [5. Additional information about Data collection and processing](<./Data-Privacy-Statement-SAP-LeanIX-Workspace/5.-Additional-information-about-Data-collection-and-processing.md>)
